@@ -326,6 +326,13 @@ class MySqlPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpenabl
         self._client = None
 
     def _request(self, query: str, params: List[str] = None) -> dict:
+        """
+        Performs a request to the database.
+
+        :param query: string with sql query to database
+        :param params: optional list of query parameters
+        :return: result of the query
+        """
         result = {'rowcount': None,
                   'items': [],
                   'column_names': None,
