@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-from pip_services3_commons.data import FilterParams
+from typing import Optional
+
+from pip_services3_commons.data import FilterParams, PagingParams
 
 from pip_services3_mysql.persistence.IdentifiableMySqlPersistence import IdentifiableMySqlPersistence
 from test.fixtures.IDummyPersistence import IDummyPersistence
@@ -15,7 +17,8 @@ class DummyMySqlPersistence(IdentifiableMySqlPersistence, IDummyPersistence):
             'CREATE TABLE `' + self._table_name + '` (id VARCHAR(32) PRIMARY KEY, `key` VARCHAR(50), `content` TEXT)')
         self._ensure_index(self._table_name + '_key', {'key': 1}, {'unique': True})
 
-    def get_page_by_filter(self, correlation_id, filter, paging, sort=None, select=None):
+    def get_page_by_filter(self, correlation_id: Optional[str], filter: FilterParams, paging: PagingParams, sort=None,
+                           select=None):
         filter = filter or FilterParams()
         key = filter.get_as_nullable_string('key')
 
@@ -25,7 +28,7 @@ class DummyMySqlPersistence(IdentifiableMySqlPersistence, IDummyPersistence):
 
         return super().get_page_by_filter(correlation_id, filter_condition, paging, None, None)
 
-    def get_count_by_filter(self, correlation_id, filter):
+    def get_count_by_filter(self, correlation_id: Optional[str], filter: FilterParams):
         filter = filter or FilterParams()
         key = filter.get_as_nullable_string('key')
 
